# Overview

Domain models are one of the core concepts to understand in the workflow orchestrator. To understand the high-level concepts of a domain model, start by reading the domain models page in the [Architecture](../../architecture/application/domainmodels.md) section of the documentation. Additionally, for an example design of domain models that could be commonly implemented by NRENs, see [this document](https://resources.geant.org/wp-content/uploads/2023/06/M7.3_Common-NREN-Network-Service-Product-Models.pdf
) created for GÉANT.
